@@ -2,10 +2,11 @@
 #' @usage NULL
 dbExistsTable_PqConnection_character <- function(conn, name, ...) {
   stopifnot(length(name) == 1L)
-  name <- dbQuoteIdentifier(conn, name)
-
-  # Convert to identifier
-  id <- dbUnquoteIdentifier(conn, name)[[1]]@name
+  # use (Un)QuoteIdentifier roundtrip instead of Id(table = name)
+  # so that quoted names (possibly incl. schema) can be passed to `name` e.g.
+  # name = dbQuoteIdentifier(conn, Id(schema = "sname", table = "tname"))
+  quoted <- dbQuoteIdentifier(conn, name)
+  id <- dbUnquoteIdentifier(conn, quoted)[[1]]
   exists_table(conn, id)
 }
 
