@@ -29,7 +29,7 @@ void DbColumn::finalize(const int n_) {
   n = n_;
 }
 
-void DbColumn::warn_type_conflicts(const String& name) const {
+void DbColumn::warn_type_conflicts(const cpp11::r_string& name) const {
   std::set<DATA_TYPE> my_data_types_seen = data_types_seen;
   DATA_TYPE dt = get_last_storage()->get_data_type();
 
@@ -52,11 +52,8 @@ void DbColumn::warn_type_conflicts(const String& name) const {
 
   if (my_data_types_seen.size() == 0) return;
 
-  String name_utf8 = name;
-  name_utf8.set_encoding(CE_UTF8);
-
   std::stringstream ss;
-  ss << "Column `" << name_utf8.get_cstring() << "`: " <<
+  ss << "Column `" << static_cast<std::string>(name) << "`: " <<
      "mixed type, first seen values of type " << format_data_type(dt) << ", " <<
      "coercing other values of type ";
 
@@ -67,7 +64,7 @@ void DbColumn::warn_type_conflicts(const String& name) const {
     ss << format_data_type(*it);
   }
 
-  warning(ss.str());
+  cpp11::warning(ss.str());
 }
 
 DbColumn::operator SEXP() const {
