@@ -2,7 +2,7 @@
 #include <plogr.h>
 
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 void init_logging(const std::string& log_level) {
   plog::init_r(log_level);
 }
