@@ -1,5 +1,5 @@
 if (Sys.getenv("GITHUB_ACTIONS") == "true" || (postgresHasDefault() && identical(Sys.getenv("NOT_CRAN"), "true"))) {
-
-  DBItest::test_all()
-
+  if (rlang::is_installed("DBItest")) {
+    DBItest::test_all()
+  }
 }
